# Generated by Django 4.2.5 on 2023-09-12 21:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0006_alter_signupcode_max_uses'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailconfirmation',
            name='sent',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
